"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TCBError = exports.getDsFullName = exports.capitalizeKey = void 0;
/**
 * 将对象的key的首字母转换为大写, 适应 yunapi 的命名风格
 *  { userName: 'xxx', id: 'xxx' } => { UserName: 'xxx', Id: 'xxxx'}
 */
function capitalizeKey(obj) {
    const result = {};
    return Object.keys(obj).reduce((acc, key) => {
        const capitalized = key.charAt(0).toUpperCase() + key.slice(1);
        acc[capitalized] = obj[key];
        return acc;
    }, result);
}
exports.capitalizeKey = capitalizeKey;
/**
 * 获取数据源完整名称, 该名称用于发布后的tcb云函数, 也用于tcb的数据库名称
 * @param ds 数据源关键信息
 * @param isPreview 是否预览
 * @returns 数据源表名
 */
function getDsFullName(ds, isPreview) {
    return `lcap-${ds.id}-${ds.name}${isPreview ? '-preview' : ''}`;
}
exports.getDsFullName = getDsFullName;
/** 预置的错误对象, 可用该对象抛出自定义错误代码及错误信息 */
class TCBError extends Error {
    constructor(code, message) {
        super(message);
        this.code = code;
        this.name = 'TCBError';
    }
}
exports.TCBError = TCBError;
